IDispatchExt

Trait IDispatchExt 

pub trait IDispatchExt {
    // Required methods
    fn call<S>(&self, name: S, args: Vec<VARIANT>) -> Result<VARIANT>
       where S: AsRef<str>;
    fn get<S>(&self, name: S) -> Result<VARIANT>
       where S: AsRef<str>;
    fn set<S>(&self, name: S, value: VARIANT) -> Result<VARIANT>
       where S: AsRef<str>;
}
Additional functions for working with an IDispatch.

Required Methods

fn call<S>(&self, name: S, args: Vec<VARIANT>) -> Result<VARIANT>
where S: AsRef<str>,

Call a function on this IDispatch

fn get<S>(&self, name: S) -> Result<VARIANT>
where S: AsRef<str>,

Get the value of a variable on this IDispatch

fn set<S>(&self, name: S, value: VARIANT) -> Result<VARIANT>
where S: AsRef<str>,

Set a value of a variable on this IDispatch

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors